/*
 * Part of "LIAB - Linux in a Box"
 * Copyright 2013 Martin von Gagern
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <stdlib.h>

#include "watchdog.h"

static int badExpected;
static const char* fname;

void restart() {
  if (badExpected) exit(EXIT_SUCCESS);
  printf("%s: restart triggered.\n", fname);
  exit(EXIT_FAILURE);
}

void fix_input() {
  if (!badExpected) exit(EXIT_SUCCESS);
  printf("%s: reached EOF without triggering restart.\n", fname);
  exit(EXIT_FAILURE);
}

int main(int argc, char** argv) {
  if (argc != 2) {
    fprintf(stderr, "Usage: %s FILE", argv[0]);
    exit(2);
  }
  fname = argv[1];
  CHK(yyin = fopen(fname, "rt"), NULL);
  badExpected = (fname[0] == 'b');
  yylex();
  return 2;
}
