/*
 * Part of "LIAB - Linux in a Box"
 * Copyright 2013 Martin von Gagern
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

%option outfile="watchdog.yy.c"
%option nodefault
%option noyywrap

%{

#include <stdio.h>
#include <stdlib.h>

#include "watchdog.h"

#define YY_INPUT(buf, result, max_size)     \
   while ((result = fread(buf, 1, max_size, yyin)) == 0) fix_input();

static int inShutdown = 0;

%}

%x EXNSTOP SUPPRESS

EOL     	\ *\r?\n
TRACELINE	{EOL}\t"at "

%%

error		|
Error		|
ERROR		|
exception	|
Exception	restart();

"Disposal was interrupted:"{EOL}"java.lang.InterruptedException"	|
"adding function ".*\.[0-9]+{EOL}					|
\n|\r|.		/* ignore this */

 /* Detect when we are doing an applet shutdown */
"OpenJDK Runtime Environment"                                   |
"file read from"                                                inShutdown = 0;
"Removing from repaint: Dispatcher["[0-9]+"]"{EOL}"drainQueue"  inShutdown = 1;

 /* Errors which are no errors if encountered during shutdown */
"Suppressing exception dialog"   if (!inShutdown) restart();

 /* The following are all right IF caused by Applet.stop. */
"java.lang.IllegalAccessException: wrong thread".*{TRACELINE}	|	
"java.lang.Exception: Stack trace"{TRACELINE}			BEGIN(EXNSTOP);

 /* EXNSTOP will search for Applet.stop and restart otherwise. */
<EXNSTOP>"de.cinderella.CindyApplet.stop(".*{TRACELINE}	BEGIN(SUPPRESS);
<EXNSTOP,SUPPRESS>.*{TRACELINE}			/* ignore trace lines */
<EXNSTOP>.|\n					restart();

 /* SUPPRESS will eat the quoted message immediately after the trace. */
<SUPPRESS>.*{EOL}"Suppressing exception dialog"	BEGIN(INITIAL);
<SUPPRESS>.|\n					BEGIN(INITIAL);

%%
